@@ -9,10 +9,16 @@ import subprocess
 import sys
 import time
 from typing import Callable, Optional, Any, Union
-from liblo import Address
+try:
+    from liblo import Address
+except ImportError:
+    from pyliblo3 import Address
 from PyQt5.QtCore import QCoreApplication, QTimer
 from PyQt5.QtXml  import QDomDocument
-import liblo
+try:
+    import liblo
+except ImportError:
+    import pyliblo3 as liblo
 from pathlib import Path
 import xml.etree.ElementTree as ET
 from io import BytesIO
@@ -1576,9 +1582,9 @@ for better organization.""")
             template_root = Path(self.root) / TemplateRoots.net_session_name
 
         template_path = template_root / template_name
+        is_factory = template_name.startswith('///')
 
-        if template_name.startswith('///'):
-            # we use here a factory session template
+        if is_factory:
             template_name = template_name.replace('///', '')
             template_path = TemplateRoots.factory_sessions / template_name
 
@@ -1592,9 +1598,10 @@ for better organization.""")
         spath = self.get_full_path(new_session_full_name)
 
         if os.path.exists(spath):
-            self._send_error(ray.Err.CREATE_FAILED,
-                             _translate("error", "Folder\n%s\nalready exists")
-                             % spath)
+            self._send_error(
+                ray.Err.CREATE_FAILED,
+                _translate("error", "Folder\n%s\nalready exists")
+                % spath)
             return
 
         if self._is_path_in_a_session_dir(spath):
@@ -1618,14 +1625,15 @@ for better organization.""")
             str(template_path), spath,
             self.prepare_template_substep1,
             self.prepare_template_aborted,
-            [new_session_full_name])
+            [new_session_full_name],
+            src_is_factory=True)
 
-    def prepare_template_substep1(self, new_session_full_name):
+    def prepare_template_substep1(self, new_session_full_name: str):
         self.adjust_files_after_copy(new_session_full_name,
                                      ray.Template.SESSION_LOAD)
         self.next_function()
 
-    def prepare_template_aborted(self, new_session_full_name):
+    def prepare_template_aborted(self, new_session_full_name: str):
         self.steps_order.clear()
         if self.path:
             self.set_server_status(ray.ServerStatus.READY)
@@ -1786,7 +1794,6 @@ for better organization.""")
         sess_name = ""
 
         if is_ray_file:
-            print('marrouubma')
             try:
                 tree = ET.parse(session_ray_file)
             except BaseException as e:
@@ -2253,7 +2260,8 @@ for better organization.""")
                         client.client_id, full_name_files, self.path,
                         self.add_client_template_step_1,
                         self.add_client_template_aborted,
-                        [src_addr, src_path, client])
+                        [src_addr, src_path, client],
+                        src_is_factory=factory)
                 else:
                     self.add_client_template_step_1(src_addr, src_path,
                                                     client)
