@@ -5,7 +5,10 @@ from pathlib import Path
 import subprocess
 import time
 from typing import TYPE_CHECKING
-from liblo import Address
+try:
+    from liblo import Address
+except ImportError:
+    from pyliblo3 import Address
 from PyQt5.QtCore import QCoreApplication, QProcess
 from PyQt5.QtXml  import QDomDocument
 
@@ -53,7 +56,7 @@ def session_operation(func):
 
         sess.remember_osc_args(path, osc_args, src_addr)
 
-        response = func(*args)
+        response = func(*args, **kwargs)
         sess.next_function()
 
         return response
@@ -74,7 +77,7 @@ def client_action(func):
 
         for client in sess.clients:
             if client.client_id == client_id:
-                response = func(*args, client)
+                response = func(*args, client, **kwargs)
                 break
         else:
             sess.send_error_no_client(src_addr, path, client_id)
@@ -640,6 +643,7 @@ class SignaledSession(OperatingSession):
                                  template_name, True)]
 
         self.steps_order += [(self.preload, session_name),
+                             # if open_off, clear all clients at close
                              (self.close, open_off),
                              self.take_place,
                              (self.load, open_off),
@@ -1069,7 +1073,7 @@ class SignaledSession(OperatingSession):
             if client_id:
                 if not client_id.replace('_', '').isalnum():
                     self.send(src_addr, '/error', path, ray.Err.CREATE_FAILED,
-                      _translate("error", f"client_id {client_id} is not alphanumeric")
+                      _translate("error", "client_id %s is not alphanumeric")
                         % client_id)
                     return
 
