@@ -1,11 +1,10 @@
 
 import sys
-
 from PyQt5.QtWidgets import QApplication
 
 import ray
-
-from patchcanvas import patchcanvas
+from client_properties_dialog import NsmClientPropertiesDialog
+from patchbay.base_elements import TransportPosition
 from daemon_manager import DaemonManager
 from gui_client import Client, TrashedClient
 from gui_signaler import Signaler
@@ -13,28 +12,31 @@ from gui_server_thread import GuiServerThread
 from gui_tools import CommandLineArgs, RS, error_text
 from main_window import MainWindow
 from nsm_child import NsmChild, NsmChildOutside
-from patchbay_manager import PatchbayManager
+from ray_patchbay_manager import RayPatchbayManager
 
 
 class Session:
     def __init__(self):
-        self.client_list = []
-        self.trashed_clients = []
-        self.favorite_list = []
-        self.recent_sessions = []
+        self.client_list = list[Client]()
+        self.trashed_clients = list[TrashedClient]()
+        self.favorite_list = list[ray.Favorite]()
+        self.recent_sessions = list[str]()
         self.name = ''
         self.path = ''
         self.notes = ''
+        self.terminal_command = ''
         self.server_status = ray.ServerStatus.OFF
 
         self.is_renameable = True
 
         self.signaler = Signaler()
-        self.patchbay_manager = PatchbayManager(self)
+        self.patchbay_manager = RayPatchbayManager(self)
 
         server = GuiServerThread.instance()
         server.start()
 
+        RS.set_signaler(self.signaler)
+
         self.daemon_manager = DaemonManager(self)
         if CommandLineArgs.daemon_url:
             self.daemon_manager.set_osc_address(CommandLineArgs.daemon_url)
@@ -58,10 +60,9 @@ class Session:
         self.daemon_manager.finish_init()
         self.patchbay_manager.finish_init()
         server.finish_init(self)
-
         self.main_win.show()
 
-        # display donations dialog under conditions
+        # display donations dialog under breizh conditions
         if not RS.is_hidden(RS.HD_Donations):
             coreff_counter = RS.settings.value('coreff_counter', 0, type=int)
             coreff_counter += 1
@@ -104,11 +105,12 @@ class Session:
                              % client_id)
         return None
 
-    def add_favorite(self, template_name: str, icon_name: str, factory: bool):
+    def add_favorite(self, template_name: str, icon_name: str,
+                     factory: bool, display_name: str):
         server = GuiServerThread.instance()
         if server:
             server.to_daemon('/ray/favorites/add', template_name,
-                            icon_name, int(factory))
+                             icon_name, int(factory), display_name)
 
     def remove_favorite(self, template_name: str, factory: bool):
         for favorite in self.favorite_list:
@@ -130,23 +132,20 @@ class Session:
         for client in self.client_list:
             client.widget.set_daemon_options(options)
 
+
 class SignaledSession(Session):
     def __init__(self):
         Session.__init__(self)
         self.signaler.osc_receive.connect(self._osc_receive)
         self.daemon_manager.start()
-
-        self.canvas_groups = []
-        self.canvas_ports = []
-        self.next_canvas_port_id = -1
         
         self.preview_notes = ''
-        self.preview_client_list = []
+        self.preview_client_list = list[ray.ClientData]()
         self.preview_started_clients = set()
-        self.preview_snapshots = []
+        self.preview_snapshots = list[str]()
         self.preview_size = -1
 
-    def _osc_receive(self, path, args):
+    def _osc_receive(self, path: str, args: tuple):
         func_path = path
         func_name = func_path.replace('/', '_')
 
@@ -157,7 +156,7 @@ class SignaledSession(Session):
     def _reply(self, path, args):
         if len(args) == 2:
             if args[0] == '/ray/session/add_executable':
-                client_id = args[1]
+                client_id: str = args[1]
 
                 for client in self.client_list:
                     if (client.client_id == client_id
@@ -203,12 +202,18 @@ class SignaledSession(Session):
         message = args[0]
         self.main_win.print_message(message)
 
+    def _ray_gui_server_terminal_command(self, path, args):
+        self.terminal_command = args[0]
+        if self.main_win.preferences_dialog is not None:
+            self.main_win.preferences_dialog.set_terminal_command(
+                self.terminal_command)
+
     def _ray_gui_server_options(self, path, args):
         options = args[0]
         self.set_daemon_options(options)
 
     def _ray_gui_server_recent_sessions(self, path, args):
-        self.recent_sessions = args
+        self.recent_sessions: list[str] = args
         self.main_win.update_recent_sessions_menu()
 
     def _ray_gui_session_name(self, path, args):
@@ -233,7 +238,7 @@ class SignaledSession(Session):
         self.notes = args[0]
         if self.main_win.notes_dialog is not None:
             self.main_win.notes_dialog.notes_updated()
-
+        
     def _ray_gui_session_notes_shown(self, path, args):
         self.main_win.edit_notes()
 
@@ -241,7 +246,7 @@ class SignaledSession(Session):
         self.main_win.edit_notes(close=True)
 
     def _ray_gui_session_sort_clients(self, path, args):
-        new_client_list = []
+        new_client_list = list[Client]()
         for client_id in args:
             client = self.get_client(client_id)
 
@@ -273,13 +278,13 @@ class SignaledSession(Session):
         if client:
             client.update_properties(*args)
 
-    def _ray_gui_client_ray_hack_update(self, path, args):
+    def _ray_gui_client_ray_hack_update(self, path, args: list):
         client_id = args.pop(0)
         client = self.get_client(client_id)
         if client and client.protocol == ray.Protocol.RAY_HACK:
             client.update_ray_hack(*args)
 
-    def _ray_gui_client_ray_net_update(self, path, args):
+    def _ray_gui_client_ray_net_update(self, path, args: list):
         client_id = args.pop(0)
         client = self.get_client(client_id)
         if client and client.protocol == ray.Protocol.RAY_NET:
@@ -300,7 +305,7 @@ class SignaledSession(Session):
 
             if status == ray.ClientStatus.REMOVED:
                 self.main_win.remove_client(client_id)
-                client.properties_dialog.close()
+                client.close_properties_dialog()
                 self.client_list.remove(client)
                 del client
 
@@ -319,13 +324,6 @@ class SignaledSession(Session):
         if client:
             client.set_dirty_state(bool(int_dirty))
 
-    def _ray_gui_client_has_optional_gui(self, path, args):
-        client_id = args[0]
-        client = self.get_client(client_id)
-
-        if client:
-            client.set_gui_enabled()
-
     def _ray_gui_client_gui_visible(self, path, args):
         client_id, int_state = args
         client = self.get_client(client_id)
@@ -349,20 +347,20 @@ class SignaledSession(Session):
             client.set_no_save_level(no_save_level)
 
     def _ray_gui_trash_add(self, path, args):
-        trashed_client = TrashedClient()
+        trashed_client = TrashedClient(self)
         trashed_client.update(*args)
         trash_action = self.main_win.trash_add(trashed_client)
         trashed_client.set_menu_action(trash_action)
         self.trashed_clients.append(trashed_client)
 
-    def _ray_gui_trash_ray_hack_update(self, path, args):
+    def _ray_gui_trash_ray_hack_update(self, path, args: list):
         client_id = args.pop(0)
         for trashed_client in self.trashed_clients:
             if trashed_client.client_id == client_id:
                 trashed_client.ray_hack = ray.RayHack.new_from(*args)
                 break
 
-    def _ray_gui_trash_ray_net_update(self, path, args):
+    def _ray_gui_trash_ray_net_update(self, path, args: list):
         client_id = args.pop(0)
         for trashed_client in self.trashed_clients:
             if trashed_client.client_id == client_id:
@@ -386,19 +384,20 @@ class SignaledSession(Session):
         self.main_win.trash_clear()
 
     def _ray_gui_favorites_added(self, path, args):
-        template_name, icon_name, int_factory = args
+        template_name, icon_name, int_factory, display_name = args
 
         for favorite in self.favorite_list:
             if (favorite.name == template_name
                     and favorite.factory == bool(int_factory)):
-                # favorite already exists, update the icon
+                # favorite already exists, update its contents
                 favorite.icon = icon_name
+                favorite.display_name = display_name
                 break
         else:
-            fav = ray.Favorite(template_name, icon_name, bool(int_factory))
-            self.favorite_list.append(fav)
+            self.favorite_list.append(ray.Favorite(
+                template_name, icon_name, bool(int_factory), display_name))
             self.signaler.favorite_added.emit(
-                template_name, icon_name, bool(int_factory))
+                template_name, icon_name, bool(int_factory), display_name)
         self.main_win.update_favorites_menu()
 
     def _ray_gui_favorites_removed(self, path, args):
@@ -481,7 +480,7 @@ class SignaledSession(Session):
         self.patchbay_manager.patchbay_announce(*args)
 
     def _ray_gui_patchbay_client_name_and_uuid(self, path, args):
-        self.patchbay_manager.client_name_and_uuid(*args)
+        self.patchbay_manager.set_group_uuid_from_name(*args)
 
     def _ray_gui_patchbay_port_added(self, path, args):
         self.patchbay_manager.add_port(*args)
@@ -491,7 +490,7 @@ class SignaledSession(Session):
 
     def _ray_gui_patchbay_port_renamed(self, path, args):
         self.patchbay_manager.rename_port(*args)
-
+        
     def _ray_gui_patchbay_metadata_updated(self, path, args):
         self.patchbay_manager.metadata_update(*args)
 
@@ -528,6 +527,10 @@ class SignaledSession(Session):
     def _ray_gui_patchbay_sample_rate(self, path, args):
         self.patchbay_manager.sample_rate_changed(*args)
 
+    def _ray_gui_patchbay_transport_position(self, path, args):
+        self.patchbay_manager.refresh_transport(TransportPosition(
+            args[0], bool(args[1]), bool(args[2]), *args[3:]))
+
     def _ray_gui_patchbay_big_packets(self, path, args):
         self.patchbay_manager.receive_big_packets(*args)
 
