@@ -1,15 +1,12 @@
-from pathlib import Path
-from signal import default_int_handler
 from typing import TYPE_CHECKING
 import time
-import os
 import subprocess
 
 from PyQt5.QtWidgets import (
     QApplication, QMainWindow, QMenu, QDialog,
     QMessageBox, QToolButton, QAbstractItemView,
-    QBoxLayout, QSystemTrayIcon, QWidget, QShortcut)
-from PyQt5.QtGui import QIcon, QDesktopServices, QFontMetrics
+    QBoxLayout, QSystemTrayIcon, QShortcut)
+from PyQt5.QtGui import QIcon, QDesktopServices, QFontMetrics, QCloseEvent
 from PyQt5.QtCore import QTimer, pyqtSlot, QUrl, QLocale, Qt
 
 import ray
@@ -17,14 +14,16 @@ import add_application_dialog
 import open_session_dialog
 import child_dialogs
 import snapshots_dialog
+import preferences_dialog
 import list_widget_clients
 
 from gui_tools import (
     RS, RayIcon, CommandLineArgs, _translate, server_status_string,
     is_dark_theme, get_code_root, get_app_icon)
+from gui_client import TrashedClient
 from gui_server_thread import GuiServerThread
 from utility_scripts import UtilityScriptLauncher
-from patchbay.base_elements import ToolDisplayed
+from patchbay.base_elements import ToolDisplayed, PortTypesViewFlag
 from patchbay.tools_widgets import PatchbayToolsWidget
 
 if TYPE_CHECKING:
@@ -139,7 +138,7 @@ class MainWindow(QMainWindow):
             self.restoreState(RS.settings.value('MainWindow/WindowState'))
         self.ui.actionShowMenuBar.activate(RS.settings.value(
             'MainWindow/ShowMenuBar', False, type=bool))
-        self.ui.actionToggleShowMessages.triggered.connect(
+        self.ui.actionToggleShowMessages.toggled.connect(
             self._show_messages_widget)
 
         self.ui.actionToggleShowMessages.setChecked(
@@ -218,8 +217,8 @@ class MainWindow(QMainWindow):
         self.ui.actionDonate.triggered.connect(self.donate)
         self.ui.actionSystemTrayIconOptions.triggered.connect(
             self._open_systray_options)
-        self.ui.actionMakeReappearDialogs.triggered.connect(
-            self._make_all_dialogs_reappear)
+        self.ui.actionPreferences.triggered.connect(
+            self._show_preferences_dialog)
 
         self.ui.lineEditServerStatus.status_pressed.connect(
             self._status_bar_pressed)
@@ -254,7 +253,7 @@ class MainWindow(QMainWindow):
         self._control_menu.addAction(self.ui.actionSessionScripts)
         self._control_menu.addAction(self.ui.actionRememberOptionalGuiStates)
         self._control_menu.addSeparator()
-        self._control_menu.addAction(self.ui.actionMakeReappearDialogs)
+        self._control_menu.addAction(self.ui.actionPreferences)
 
         self._control_tool_button = self.ui.toolBar.widgetForAction(
             self.ui.actionControlMenu)
@@ -342,11 +341,11 @@ class MainWindow(QMainWindow):
         self.ui.actionSessionNotes.setIcon(RayIcon('notes', dark))
         self.ui.toolButtonNotes.setIcon(RayIcon('notes', dark))
         self.ui.actionDesktopsMemory.setIcon(RayIcon('view-list-icons', dark))
-
         self.ui.toolButtonSessionMenu.setIcon(RayIcon('application-menu', dark))
-
         self.ui.listWidget.set_session(self.session)
-        
+        self.ui.listWidget.currentItemChanged.connect(
+            self._list_widget_item_changed)
+
         # concerns patchbay filters bar (activable with Ctrl+F)
         self.ui.framePatchbayFilters.set_patchbay_manager(
             self.session.patchbay_manager)
@@ -392,16 +391,20 @@ class MainWindow(QMainWindow):
         self.hidden_maximized = False
         
         # systray icon and related
-        self._wild_shutdown = RS.settings.value(
+        self.wild_shutdown: bool = RS.settings.value(
             'wild_shutdown', False, type=bool)
-        self._systray_mode = RS.settings.value(
+        self.systray_mode: int = RS.settings.value(
             'systray_mode', ray.Systray.SESSION_ONLY, type=int)
-        self._reversed_systray_menu = RS.settings.value(
+        self.reversed_systray_menu: bool = RS.settings.value(
             'reversed_systray_menu', False, type=bool)
 
+        systray_icon = QIcon.fromTheme('raysession')
+        if systray_icon.isNull():
+            systray_icon = QIcon(':main_icon/48x48/raysession')
+
         self._systray = QSystemTrayIcon(self)
         self._systray.activated.connect(self._systray_activated)
-        self._systray.setIcon(QIcon(':main_icon/48x48/raysession'))
+        self._systray.setIcon(systray_icon)
         self._systray.setToolTip(ray.APP_TITLE)
         self._systray_menu = QMenu()
         self._systray_menu_add = QMenu(self._systray_menu)
@@ -409,11 +412,13 @@ class MainWindow(QMainWindow):
         self._build_systray_menu()
 
         if (not CommandLineArgs.under_nsm
-            and (self._systray_mode == ray.Systray.ALWAYS
-                    or (self._systray_mode == ray.Systray.SESSION_ONLY
+            and (self.systray_mode == ray.Systray.ALWAYS
+                    or (self.systray_mode == ray.Systray.SESSION_ONLY
                         and self.session.server_status != ray.ServerStatus.OFF))):
             self._systray.show()
 
+        self.preferences_dialog: preferences_dialog.PreferencesDialog = None
+
         self._startup_time = time.time()
 
     def _splitter_session_vs_messages_moved(self, pos: int, index: int):
@@ -490,37 +495,37 @@ class MainWindow(QMainWindow):
     def _open_file_manager(self):
         self.to_daemon('/ray/session/open_folder')
 
-    def _open_systray_options(self):
-        dialog = child_dialogs.SystrayManagement(self)
-        dialog.set_systray_mode(self._systray_mode)
-        dialog.set_wild_shutdown(self._wild_shutdown)
-        dialog.set_reversed_state(self._reversed_systray_menu)
-
-        dialog.exec()
-        if not dialog.result():
-            return
-
-        self._systray_mode = dialog.get_systray_mode()
-        self._wild_shutdown = dialog.wild_shutdown()
-        reversed_systray_menu = dialog.menu_should_be_reversed()
-        RS.settings.setValue('systray_mode', self._systray_mode)
-        RS.settings.setValue('wild_shutdown', self._wild_shutdown)
-        RS.settings.setValue('reversed_systray_menu', reversed_systray_menu)
-
-        if reversed_systray_menu != self._reversed_systray_menu:
-            self._reversed_systray_menu = reversed_systray_menu
+    def change_systray_options(
+            self, systray_mode: int, wild_shutdown: bool,
+            reversed_systray_menu: bool):        
+        self.systray_mode = systray_mode
+        self.wild_shutdown = wild_shutdown
+        
+        if reversed_systray_menu != self.reversed_systray_menu:
+            self.reversed_systray_menu = reversed_systray_menu
             self._build_systray_menu()
 
-        if self._systray_mode == ray.Systray.OFF:
+        RS.settings.setValue('systray_mode', self.systray_mode)
+        RS.settings.setValue('wild_shutdown', self.wild_shutdown)
+        RS.settings.setValue('reversed_systray_menu',
+                             self.reversed_systray_menu)
+
+        if self.systray_mode == ray.Systray.OFF:
             self._systray.hide()
-        elif self._systray_mode == ray.Systray.SESSION_ONLY:
+        elif self.systray_mode == ray.Systray.SESSION_ONLY:
             if self.session.server_status == ray.ServerStatus.OFF:
                 self._systray.hide()
             else:
                 self._systray.show()
-        elif self._systray_mode == ray.Systray.ALWAYS:
+        elif self.systray_mode == ray.Systray.ALWAYS:
             self._systray.show()
 
+    def _open_systray_options(self):
+        self._show_preferences_dialog()
+        if self.preferences_dialog is not None:
+            self.preferences_dialog.set_on_tab(
+                preferences_dialog.PreferencesTab.SYSTRAY)
+
     def _raise_window(self):
         if self.mouse_is_inside:
             self.activateWindow()
@@ -560,7 +565,7 @@ class MainWindow(QMainWindow):
         self._flash_open_bool = not self._flash_open_bool
 
     def _quit_app(self):
-        if self._wild_shutdown and not CommandLineArgs.under_nsm:
+        if self.wild_shutdown and not CommandLineArgs.under_nsm:
             self.daemon_manager.disannounce()
             QTimer.singleShot(10, QApplication.quit)
             return
@@ -721,15 +726,16 @@ class MainWindow(QMainWindow):
 
     def _internal_manual(self):
         short_locale = 'en'
-        manual_dir = "%s/manual" % get_code_root()
+        manual_dir = get_code_root() / 'manual'
         locale_str = QLocale.system().name()
+        manual_file = manual_dir / locale_str[:2] / 'manual.html'
+        
         if (len(locale_str) > 2 and '_' in locale_str
-                and os.path.isfile(
-                    "%s/%s/manual.html" % (manual_dir, locale_str[:2]))):
+                and manual_file.is_file()):
             short_locale = locale_str[:2]
 
         QDesktopServices.openUrl(
-            QUrl("%s/%s/manual.html" % (manual_dir, short_locale)))
+            QUrl(str(manual_dir / short_locale / 'manual.html')))
 
     def _save_session(self):
         self.to_daemon('/ray/session/save')
@@ -752,10 +758,13 @@ class MainWindow(QMainWindow):
 
         if dialog.result():
             template_name, factory = dialog.get_selected_template()
+            unique_id = dialog.get_selected_unique_id()
             self.to_daemon(
                 '/ray/session/add_client_template',
                 int(factory),
-                template_name)
+                template_name,
+                'start',
+                unique_id)
 
     def _add_executable(self):
         if self.session.server_status in (
@@ -932,7 +941,7 @@ class MainWindow(QMainWindow):
         self.ui.frameCurrentSession.setEnabled(
             bool(server_status != ray.ServerStatus.OFF))
 
-        if self._systray_mode == ray.Systray.SESSION_ONLY:
+        if self.systray_mode == ray.Systray.SESSION_ONLY:
             if server_status == ray.ServerStatus.OFF:
                 self._systray.hide()
             else:
@@ -1033,18 +1042,6 @@ class MainWindow(QMainWindow):
                 dialog = child_dialogs.WaitingCloseUserDialog(self)
                 dialog.exec()
 
-    def _make_all_dialogs_reappear(self):
-        ok = QMessageBox.question(
-            self,
-            _translate('hidden_dialogs', 'Make reappear dialog windows'),
-            _translate('hidden_dialogs',
-                       'Do you want to make reappear all dialogs you wanted to hide ?'))
-
-        if not ok:
-            return
-
-        RS.reset_hiddens()
-
     def _build_systray_menu(self):
         is_shown = self._systray.isVisible()
         self._systray.hide()
@@ -1067,7 +1064,7 @@ class MainWindow(QMainWindow):
                  ray.ServerStatus.WAIT_USER, ray.ServerStatus.OUT_SAVE,
                  ray.ServerStatus.OUT_SNAPSHOT))
 
-        if self._reversed_systray_menu:
+        if self.reversed_systray_menu:
             self._systray_menu.addAction(self.ui.actionQuit)
             self._systray_menu.addSeparator()
             self._systray_menu.addAction(self.ui.actionSystemTrayIconOptions)
@@ -1098,7 +1095,11 @@ class MainWindow(QMainWindow):
         if is_shown:
             self._systray.show()
 
-    def _systray_activated(self):
+    def _systray_activated(self, reason: QSystemTrayIcon.ActivationReason):
+        if reason not in (QSystemTrayIcon.Trigger,
+                          QSystemTrayIcon.DoubleClick):
+            return
+
         wayland = bool(ray.get_window_manager() == ray.WindowManager.WAYLAND)
 
         if self.isMinimized():
@@ -1168,9 +1169,16 @@ class MainWindow(QMainWindow):
                 | ToolDisplayed.XRUNS
                 | ToolDisplayed.DSP_LOAD)
             
-            self.ui.toolBar.set_default_displayed_widgets(
-                default_disp_wdg.filtered_by_string(
-                    RS.settings.value('tool_bar/jack_elements', '', type=str)))
+            default_disp_wdg = default_disp_wdg.filtered_by_string(
+                RS.settings.value('tool_bar/jack_elements', '', type=str))
+            
+            self.ui.toolBar.set_default_displayed_widgets(default_disp_wdg)
+            
+            if not default_disp_wdg & ToolDisplayed.PORT_TYPES_VIEW:
+                RS.settings.setValue(
+                    'Canvas/default_port_types_view',
+                    PortTypesViewFlag.ALL.value)
+
         self._canvas_menu = self.ui.menuBar.addMenu(canvas_menu)
 
     def create_client_widget(self, client):
@@ -1198,6 +1206,8 @@ class MainWindow(QMainWindow):
         self.ui.listWidget.setObjectName("listWidget")
         self.ui.listWidget.set_session(self.session)
         self.ui.verticalLayout.addWidget(self.ui.listWidget)
+        self.ui.listWidget.currentItemChanged.connect(
+            self._list_widget_item_changed)
 
     def set_nsm_locked(self, nsm_locked: bool):
         self.ui.actionNewSession.setEnabled(not nsm_locked)
@@ -1230,6 +1240,14 @@ class MainWindow(QMainWindow):
 
         self.ui.frameCurrentSession.setStyleSheet(frame_style_sheet)
 
+    def _list_widget_item_changed(self, current: list_widget_clients.ClientItem,
+                                  previous):
+        if current is None:
+            return
+
+        self.session.patchbay_manager.select_client_box(
+            current.widget.client.jack_client_name)
+
     def set_daemon_options(self, options):
         self.ui.actionBookmarkSessionFolder.setChecked(
             bool(options & ray.Option.BOOKMARK_SESSION))
@@ -1262,6 +1280,12 @@ class MainWindow(QMainWindow):
         dialog = child_dialogs.DonationsDialog(self, display_no_again)
         dialog.exec()
 
+    def _show_preferences_dialog(self):
+        if self.preferences_dialog is None:
+            self.preferences_dialog = preferences_dialog.PreferencesDialog(self)
+        
+        self.preferences_dialog.show()
+
     def edit_notes(self, close=False):
         icon_str = 'notes'
         if close:
@@ -1422,7 +1446,7 @@ class MainWindow(QMainWindow):
         dialog = child_dialogs.OpenNsmSessionInfoDialog(self)
         dialog.exec()
 
-    def trash_add(self, trashed_client):
+    def trash_add(self, trashed_client: TrashedClient):
         act_x_trashed = self._trash_menu.addAction(
             get_app_icon(trashed_client.icon, self),
             trashed_client.prettier_name())
@@ -1480,7 +1504,7 @@ class MainWindow(QMainWindow):
     def launch_favorite(self):
         template_name, factory = self.sender().data()
         self.to_daemon('/ray/session/add_client_template',
-                       int(factory), template_name)
+                       int(factory), template_name, 'start', '')
 
     def toggle_patchbay_filters_bar(self):
         if not self.ui.graphicsView.isVisible():
@@ -1527,14 +1551,14 @@ class MainWindow(QMainWindow):
         self._script_info_dialog.show()
 
     def hide_script_info_dialog(self):
-        if self._script_info_dialog:
+        if self._script_info_dialog is not None:
             self._script_info_dialog.close()
 
         del self._script_info_dialog
         self._script_info_dialog = None
 
     def show_script_user_action_dialog(self, text: str):
-        if self._script_action_dialog:
+        if self._script_action_dialog is not None:
             self._script_action_dialog.close()
             del self._script_action_dialog
             self.to_daemon(
@@ -1590,11 +1614,14 @@ class MainWindow(QMainWindow):
         RS.settings.setValue(
             'tool_bar/icons_only',
             self.ui.toolBar.force_main_actions_icons_only)
+        RS.settings.setValue(
+            'Canvas/default_port_types_view',
+            self.session.patchbay_manager.port_types_view.value)
         RS.settings.sync()
 
     # Reimplemented Qt Functions
 
-    def closeEvent(self, event):
+    def closeEvent(self, event: QCloseEvent):        
         self.save_window_settings()
         self.session.patchbay_manager.save_patchcanvas_cache()
         self.hidden_maximized = self.isMaximized()
