@@ -6,7 +6,10 @@ import json
 import subprocess
 from typing import TYPE_CHECKING
 
-from liblo import Server, Address
+try:
+    from liblo import Server, Address
+except ImportError:
+    from pyliblo3 import Server, Address
 
 if TYPE_CHECKING:
     from ray_jackpatch_to_osc import MainObject, TransportPosition
