@@ -5,6 +5,7 @@ from enum import IntEnum
 import os
 import signal
 import sys
+from typing import Optional
 import warnings
 
 import osc_server
@@ -12,7 +13,19 @@ import threading
 import time
 
 import jacklib
-from jacklib.helpers import c_char_p_p_to_list, voidptr2str
+from jacklib.helpers import c_char_p_p_to_list
+from jacklib.enums import JackOptions, JackPortFlags, JackMetadata
+
+# check ALSA LIB
+try:
+    from pyalsa.alsaseq import SEQ_LIB_VERSION_STR
+    ALSA_VERSION_LIST = [int(num) for num in SEQ_LIB_VERSION_STR.split('.')]
+    assert ALSA_VERSION_LIST >= [1, 2, 4]
+    ALSA_LIB_OK = True
+    from alsa_manager import AlsaManager
+except:
+    ALSA_LIB_OK = False
+    
 
 PORT_TYPE_NULL = 0
 PORT_TYPE_AUDIO = 1
@@ -22,7 +35,6 @@ EXISTENCE_PATH = '/tmp/RaySession/patchbay_daemons/'
 
 
 
-
 # Define a context manager to suppress stdout and stderr.
 class suppress_stdout_stderr(object):
     '''
@@ -97,8 +109,8 @@ class JackPort:
         elif port_type_str == jacklib.JACK_DEFAULT_MIDI_TYPE:
             self.type = PORT_TYPE_MIDI
             
-        order_prop = jacklib.get_property(self.uuid,
-                                          jacklib.JACK_METADATA_ORDER)
+        order_prop = jacklib.get_property(
+            self.uuid, JackMetadata.ORDER)
 
         ret, alias_1, alias_2 = jacklib.port_get_aliases(port_ptr)
         if ret:
@@ -117,6 +129,7 @@ class MainObject:
     client_names_queue = list[str]()
     jack_running = False
     osc_server = None
+    alsa_mng: Optional['AlsaManager'] = None
     terminate = False
     jack_client = None
     samplerate = 48000
@@ -127,6 +140,7 @@ class MainObject:
     
     def __init__(self, daemon_port: str, gui_url: str):
         self._daemon_port = daemon_port
+        self.ALSA_LIB_OK = ALSA_LIB_OK
         self.last_sent_dsp_load = 0
         self.max_dsp_since_last_sent = 0.00
         self._waiting_jack_client_open = True
@@ -136,6 +150,10 @@ class MainObject:
         self.osc_server.set_tmp_gui_url(gui_url)
         self.write_existence_file()
         self.start_jack_client()
+        
+        if ALSA_LIB_OK:
+            self.alsa_mng = AlsaManager(self)
+            self.alsa_mng.add_all_ports()
     
     @staticmethod
     def get_metadata_value_str(prop: jacklib.Property) -> str:
@@ -229,6 +247,9 @@ class MainObject:
         if self.jack_running:
             self.get_all_ports_and_connections()
             self.osc_server.server_restarted()
+            
+        if self.alsa_mng is not None:
+            self.alsa_mng.add_all_ports()
     
     def remember_dsp_load(self):
         self.max_dsp_since_last_sent = max(
@@ -264,7 +285,7 @@ class MainObject:
         transport_position = TransportPosition(
             int(pos.frame),
             bool(state),
-            bool(pos.valid & jacklib.JackPositionBBT),
+            bool(pos.valid & jacklib.JackPositionBits.POSITION_BBT),
             int(pos.bar),
             int(pos.beat),
             int(pos.tick),
@@ -276,6 +297,18 @@ class MainObject:
         self.last_transport_pos = transport_position
         self.osc_server.send_transport_position(transport_position)
     
+    def connect_ports(self, port_out_name: str, port_in_name: str,
+                      disconnect=False):
+        if self.alsa_mng is not None and port_out_name.startswith(':ALSA_OUT:'):
+            self.alsa_mng.connect_ports(
+                port_out_name, port_in_name, disconnect=disconnect)
+            return
+
+        if disconnect:
+            jacklib.disconnect(self.jack_client, port_out_name, port_in_name)
+        else:
+            jacklib.connect(self.jack_client, port_out_name, port_in_name)
+    
     def start_loop(self):
         n = 0
 
@@ -308,6 +341,11 @@ class MainObject:
         if self.jack_running:
             jacklib.deactivate(self.jack_client)
             jacklib.client_close(self.jack_client)
+
+        if self.alsa_mng is not None:
+            self.alsa_mng.stop_events_loop()
+            del self.alsa_mng
+
         self.remove_existence_file()
         del self.osc_server
     
@@ -324,7 +362,7 @@ class MainObject:
         with suppress_stdout_stderr():
             self.jack_client = jacklib.client_open(
                 "ray-patch_to_osc",
-                jacklib.JackNoStartServer | jacklib.JackSessionID,
+                JackOptions.NO_START_SERVER | JackOptions.SESSION_ID,
                 None)
 
         self._waiting_jack_client_open = False
@@ -337,7 +375,6 @@ class MainObject:
             self.jack_running = True
             self.set_registrations()
             self.get_all_ports_and_connections()
-            self.osc_server.set_jack_client(self.jack_client)
             self.samplerate = jacklib.get_sample_rate(self.jack_client)
             self.buffer_size = jacklib.get_buffer_size(self.jack_client)
             self.osc_server.server_restarted()
@@ -395,10 +432,11 @@ class MainObject:
                 client_names.append(client_name)
 
             # get port metadatas
-            for key in (jacklib.JACK_METADATA_CONNECTED,
-                        jacklib.JACK_METADATA_ORDER,
-                        jacklib.JACK_METADATA_PORT_GROUP,
-                        jacklib.JACK_METADATA_PRETTY_NAME):
+            for key in (JackMetadata.CONNECTED,
+                        JackMetadata.ORDER,
+                        JackMetadata.PORT_GROUP,
+                        JackMetadata.PRETTY_NAME,
+                        JackMetadata.SIGNAL_TYPE):
                 prop = jacklib.get_property(jport.uuid, key)
                 if prop is None:
                     continue
@@ -409,7 +447,7 @@ class MainObject:
                      'key': key,
                      'value': value})
 
-            if jport.flags & jacklib.JackPortIsInput:
+            if jport.flags & JackPortFlags.IS_INPUT:
                 continue
 
             port_ptr = jacklib.port_by_name(self.jack_client, jport.name)
@@ -430,8 +468,8 @@ class MainObject:
             
             # we only look for icon_name now, but in the future other client
             # metadatas could be enabled
-            for key in (jacklib.JACK_METADATA_ICON_NAME,):
-                prop = jacklib.get_property(int(uuid), jacklib.JACK_METADATA_ICON_NAME)
+            for key in (JackMetadata.ICON_NAME,):
+                prop = jacklib.get_property(int(uuid), JackMetadata.ICON_NAME)
                 if prop is None:
                     continue
                 value = self.get_metadata_value_str(prop)
@@ -478,12 +516,13 @@ class MainObject:
         if register:
             jport = JackPort(port_name, self.jack_client, port_ptr)
             self.port_list.append(jport)
-            self.osc_server.port_added(jport)
+            self.osc_server.port_added(
+                jport.name, jport.type, jport.flags, jport.uuid)
         else:
             for jport in self.port_list:
                 if jport.name == port_name:
                     self.port_list.remove(jport)
-                    self.osc_server.port_removed(jport)
+                    self.osc_server.port_removed(jport.name)
                     break
         return 0
     
@@ -493,7 +532,7 @@ class MainObject:
             if jport.name == str(old_name.decode()):
                 ex_name = jport.name
                 jport.name = str(new_name.decode())
-                self.osc_server.port_renamed(jport, ex_name)
+                self.osc_server.port_renamed(ex_name, jport.name)
                 break
         return 0
     
@@ -523,11 +562,11 @@ class MainObject:
         
         value = ''
 
-        if name and type_ != jacklib.PropertyDeleted:
+        if name and type_ != jacklib.JackPropertyChange.DELETED:
             prop = jacklib.get_property(uuid, name)
             if prop is None:
                 return 0
-            
+
             value = self.get_metadata_value_str(prop)
         
         for metadata in self.metadata_list:
@@ -537,7 +576,7 @@ class MainObject:
         else:
             self.metadata_list.append(
                 {'uuid': uuid, 'key': name, 'value': value})
-        
+
         self.osc_server.metadata_updated(uuid, name, value)
 
         return 0
@@ -592,4 +631,4 @@ if __name__ == '__main__':
     signal.signal(signal.SIGINT, MainObject.signal_handler)
     signal.signal(signal.SIGTERM, MainObject.signal_handler)
     
-    main_process()
+    main_process()
\ No newline at end of file
